<?php

namespace Litepci\Service\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litepci\Service\Interfaces\DeliverableRepositoryInterface;

class DeliverablePublicController extends BaseController
{
    // use DeliverableWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litepci\Deliverable\Interfaces\DeliverableRepositoryInterface $deliverable
     *
     * @return type
     */
    public function __construct(DeliverableRepositoryInterface $deliverable)
    {
        $this->repository = $deliverable;
        parent::__construct();
    }

    /**
     * Show deliverable's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $deliverables = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('service::deliverable.names'))
            ->view('service::public.deliverable.index')
            ->data(compact('deliverables'))
            ->output();
    }


    /**
     * Show deliverable.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $deliverable = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($deliverable->name . trans('service::deliverable.name'))
            ->view('service::public.deliverable.show')
            ->data(compact('deliverable'))
            ->output();
    }

}
