<?php

namespace Litepci\Service\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepci\Service\Models\Deliverable;

class DeliverablePolicy
{

    /**
     * Determine if the given user can view the deliverable.
     *
     * @param UserPolicy $user
     * @param Deliverable $deliverable
     *
     * @return bool
     */
    public function view(UserPolicy $user, Deliverable $deliverable)
    {
        if ($user->canDo('service.deliverable.view') && $user->isAdmin()) {
            return true;
        }

        return $deliverable->user_id == user_id() && $deliverable->user_type == user_type();
    }

    /**
     * Determine if the given user can create a deliverable.
     *
     * @param UserPolicy $user
     * @param Deliverable $deliverable
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('service.deliverable.create');
    }

    /**
     * Determine if the given user can update the given deliverable.
     *
     * @param UserPolicy $user
     * @param Deliverable $deliverable
     *
     * @return bool
     */
    public function update(UserPolicy $user, Deliverable $deliverable)
    {
        if ($user->canDo('service.deliverable.edit') && $user->isAdmin()) {
            return true;
        }

        return $deliverable->user_id == user_id() && $deliverable->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given deliverable.
     *
     * @param UserPolicy $user
     * @param Deliverable $deliverable
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Deliverable $deliverable)
    {
        return $deliverable->user_id == user_id() && $deliverable->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given deliverable.
     *
     * @param UserPolicy $user
     * @param Deliverable $deliverable
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Deliverable $deliverable)
    {
        if ($user->canDo('service.deliverable.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given deliverable.
     *
     * @param UserPolicy $user
     * @param Deliverable $deliverable
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Deliverable $deliverable)
    {
        if ($user->canDo('service.deliverable.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
